@@ -489,8 +489,7 @@ void ApplicationContextBase::locateResources()
         rgm.addResourceLocation(mediaDir + "/Terrain", "FileSystem", Ogre::RGN_INTERNAL);
 #endif
 #ifdef OGRE_BUILD_COMPONENT_RTSHADERSYSTEM
-        rgm.addResourceLocation(mediaDir + "/RTShaderLib/GLSL", "FileSystem", Ogre::RGN_INTERNAL);
-        rgm.addResourceLocation(mediaDir + "/RTShaderLib/HLSL_Cg", "FileSystem", Ogre::RGN_INTERNAL);
+        rgm.addResourceLocation(mediaDir + "/RTShaderLib", "FileSystem", Ogre::RGN_INTERNAL);
 #endif
     }
 }
@@ -509,21 +508,6 @@ void ApplicationContextBase::reconfigure(const Ogre::String &renderer, Ogre::Nam
     for (auto & option : options)
     {
         rs->setConfigOption(option.first, option.second);
-
-#if OGRE_PLATFORM == OGRE_PLATFORM_APPLE_IOS
-        // Change the viewport orientation on the fly if requested
-        if(option.first == "Orientation")
-        {
-            Ogre::RenderWindow* win = getRenderWindow();
-
-            if (option.second == "Landscape Left")
-                win->getViewport(0)->setOrientationMode(Ogre::OR_LANDSCAPELEFT, true);
-            else if (option.second == "Landscape Right")
-                win->getViewport(0)->setOrientationMode(Ogre::OR_LANDSCAPERIGHT, true);
-            else if (option.second == "Portrait")
-                win->getViewport(0)->setOrientationMode(Ogre::OR_PORTRAIT, true);
-        }
-#endif
     }
 
 #if OGRE_PLATFORM == OGRE_PLATFORM_APPLE_IOS
