@@ -110,7 +110,7 @@ bool IntegratedPSSM3::preAddToRenderState(const RenderState* renderState,
                                          Pass* srcPass, Pass* dstPass)
 {
     if (!srcPass->getParent()->getParent()->getReceiveShadows() ||
-        renderState->getLightCount().isZeroLength())
+        renderState->getLightCount() == 0)
         return false;
 
     mIsD3D9 = ShaderGenerator::getSingleton().getTargetLanguage() == "hlsl" &&
@@ -178,6 +178,22 @@ bool IntegratedPSSM3::setParameter(const String& name, const String& value)
     return false;
 }
 
+void IntegratedPSSM3::setParameter(const String& name, const Any& value)
+{
+    if(name == "split_points")
+    {
+        setSplitPoints(any_cast<SplitPointList>(value));
+        return;
+    }
+    else if (name == "debug")
+    {
+        mDebug = any_cast<bool>(value);
+        return;
+    }
+
+    SubRenderState::setParameter(name, value);
+}
+
 //-----------------------------------------------------------------------
 bool IntegratedPSSM3::resolveParameters(ProgramSet* programSet)
 {
@@ -289,7 +305,7 @@ bool IntegratedPSSM3::addVSInvocation(Function* vsMain, const int groupOrder)
 
     while(it != mShadowTextureParamsList.end())
     {
-        stage.callFunction(FFP_FUNC_TRANSFORM, it->mWorldViewProjMatrix, mVSInPos, it->mVSOutLightPosition);
+        stage.callBuiltin("mul", it->mWorldViewProjMatrix, mVSInPos, it->mVSOutLightPosition);
         ++it;
     }
 
@@ -367,7 +383,7 @@ SubRenderState* IntegratedPSSM3Factory::createInstance(ScriptCompiler* compiler,
                 SubRenderState* subRenderState = createOrRetrieveInstance(translator);
                 IntegratedPSSM3* pssmSubRenderState = static_cast<IntegratedPSSM3*>(subRenderState);
 
-                pssmSubRenderState->setSplitPoints(splitPointList);
+                pssmSubRenderState->setParameter("split_points", splitPointList);
 
                 return pssmSubRenderState;
             }
