@@ -51,48 +51,13 @@ static GpuConstantType typeFromContent(Parameter::Content content)
     case Parameter::SPC_POSITION_LIGHT_SPACE7:
     case Parameter::SPC_TANGENT_OBJECT_SPACE:
         return GCT_FLOAT4;
-    case Parameter::SPC_NORMAL_TANGENT_SPACE:
     case Parameter::SPC_NORMAL_OBJECT_SPACE:
     case Parameter::SPC_NORMAL_WORLD_SPACE:
     case Parameter::SPC_NORMAL_VIEW_SPACE:
-    case Parameter::SPC_POSTOCAMERA_TANGENT_SPACE:
     case Parameter::SPC_POSTOCAMERA_OBJECT_SPACE:
     case Parameter::SPC_POSTOCAMERA_VIEW_SPACE:
     case Parameter::SPC_POSITION_VIEW_SPACE:
     case Parameter::SPC_POSITION_WORLD_SPACE:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE0:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE1:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE2:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE3:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE4:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE5:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE6:
-    case Parameter::SPC_LIGHTDIRECTION_OBJECT_SPACE7:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE0:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE1:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE2:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE3:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE4:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE5:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE6:
-    case Parameter::SPC_POSTOLIGHT_OBJECT_SPACE7:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE0:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE1:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE2:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE3:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE4:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE5:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE6:
-    case Parameter::SPC_LIGHTDIRECTION_TANGENT_SPACE7:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE0:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE1:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE2:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE3:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE4:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE5:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE6:
-    case Parameter::SPC_POSTOLIGHT_TANGENT_SPACE7:
-    case Parameter::SPC_LIGHTDIRECTION_VIEW_SPACE0:
         return GCT_FLOAT3;
     case Parameter::SPC_POINTSPRITE_COORDINATE:
         return GCT_FLOAT2;
