@@ -1314,6 +1314,20 @@ const String& ShaderGenerator::getRTShaderScheme(size_t index) const
     else return BLANKSTRING;
 }
 
+void ShaderGenerator::_markNonFFP(const TextureUnitState* tu)
+{
+    auto pass = tu->getParent();
+    auto texureIdx = pass->getTextureUnitStateIndex(tu);
+
+    // add to blacklist
+    std::set<uint16> nonFFP_TUS;
+    auto any = pass->getUserObjectBindings().getUserAny("_RTSS_nonFFP_TUS");
+    if(any.has_value())
+        nonFFP_TUS = any_cast<std::set<uint16>>(any);
+    nonFFP_TUS.insert(texureIdx);
+    pass->getUserObjectBindings().setUserAny("_RTSS_nonFFP_TUS", nonFFP_TUS);
+}
+
 //-----------------------------------------------------------------------------
 
 bool ShaderGenerator::getIsFinalizing() const
@@ -1360,16 +1374,6 @@ ShaderGenerator::SGPass::~SGPass()
 }
 
 //-----------------------------------------------------------------------------
-#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
-static void addDefaultSubRenderStates(const TargetRenderStatePtr& renderState, Pass* srcPass, Pass* dstPass)
-{
-    RenderState ffpTemplate;
-    ffpTemplate.addTemplateSubRenderStates(
-        {SRS_TRANSFORM, SRS_VERTEX_COLOUR, SRS_PER_PIXEL_LIGHTING, SRS_TEXTURING, SRS_FOG, SRS_ALPHA_TEST});
-    renderState->link(ffpTemplate, srcPass, dstPass);
-}
-#endif
-
 void ShaderGenerator::SGPass::buildTargetRenderState()
 {   
     if(mSrcPass->isProgrammable() && !mParent->overProgrammablePass() && !isIlluminationPass()) return;
@@ -1380,7 +1384,7 @@ void ShaderGenerator::SGPass::buildTargetRenderState()
     auto targetRenderState = std::make_shared<TargetRenderState>();
 
     // Set light properties.
-    Vector3i lightCount(0, 0, 0);
+    int32 lightCount = 0;
 
     // Use light count definitions of the custom render state if exists.
     if (mCustomRenderState != NULL && mCustomRenderState->getLightCountAutoUpdate() == false)
@@ -1397,21 +1401,17 @@ void ShaderGenerator::SGPass::buildTargetRenderState()
     
     targetRenderState->setLightCount(lightCount);
 
-    // Link the target render state with the custom render state of this pass if exists.
-    if (mCustomRenderState != NULL)
-    {
-        targetRenderState->link(*mCustomRenderState, mSrcPass, mDstPass);
-    }
-
     // Link the target render state with the scheme render state of the shader generator.
     if (renderStateGlobal != NULL)
     {
         targetRenderState->link(*renderStateGlobal, mSrcPass, mDstPass);
     }
 
-#ifdef RTSHADER_SYSTEM_BUILD_CORE_SHADERS
-    addDefaultSubRenderStates(targetRenderState, mSrcPass, mDstPass);
-#endif
+    // Link the target render state with the custom render state of this pass if exists.
+    if (mCustomRenderState != NULL)
+    {
+        targetRenderState->link(*mCustomRenderState, mSrcPass, mDstPass);
+    }
 
     targetRenderState->acquirePrograms(mDstPass);
     mDstPass->getUserObjectBindings().setUserAny(TargetRenderState::UserKey, targetRenderState);
@@ -1668,7 +1668,10 @@ ShaderGenerator::SGScheme::~SGScheme()
 RenderState* ShaderGenerator::SGScheme::getRenderState()
 {
     if (!mRenderState)
+    {
         mRenderState.reset(new RenderState);
+        mRenderState->resetToBuiltinSubRenderStates();
+    }
 
     return mRenderState.get();
 }
@@ -1758,18 +1761,11 @@ void ShaderGenerator::SGScheme::synchronizeWithLightSettings()
 
         const LightList& lightList =  sceneManager->_getLightsAffectingFrustum();
         
-        Vector3i sceneLightCount(0, 0, 0);
-        for (unsigned int i=0; i < lightList.size(); ++i)
-        {
-            sceneLightCount[lightList[i]->getType()]++;
-        }
-        
-        auto currLightCount = mRenderState->getLightCount();
-
-        auto lightDiff = currLightCount - sceneLightCount;
+        int32 sceneLightCount = lightList.size();
+        int32 currLightCount = mRenderState->getLightCount();
 
         // Case new light appeared -> invalidate. But dont invalidate the other way as shader compilation is costly.
-        if (!(Vector3i(-1) < lightDiff))
+        if ((currLightCount - sceneLightCount) < 0)
         {
             LogManager::getSingleton().stream(LML_TRIVIAL)
                 << "RTSS: invalidating scheme " << mName << " - lights changed " << currLightCount
