@@ -41,7 +41,6 @@ THE SOFTWARE.
 
 #include "OgreShaderGenerator.h"
 #include "OgreTerrainRTShaderSRS.h"
-#include "OgreShaderExIntegratedPSSM3.h"
 
 #include <fstream>
 #include <string>
@@ -49,19 +48,19 @@ THE SOFTWARE.
 namespace Ogre
 {
     //---------------------------------------------------------------------
-    TerrainMaterialGeneratorA::TerrainMaterialGeneratorA()
+    TerrainMaterialGeneratorA::TerrainMaterialGeneratorA() :
+        mLightmapEnabled(true),
+        mCompositeMapEnabled(true),
+        mReceiveDynamicShadows(true),
+        mLowLodShadows(false)
     {
         // define the layers
         // We expect terrain textures to have no alpha, so we use the alpha channel
         // in the albedo texture to store specular reflection
         // similarly we double-up the normal and height (for parallax)
-        mLayerDecl.samplers.push_back(TerrainLayerSampler("albedo_specular", PF_BYTE_RGBA));
-        mLayerDecl.samplers.push_back(TerrainLayerSampler("normal_height", PF_BYTE_RGBA));
-        
-        mProfiles.push_back(OGRE_NEW SM2Profile(this, "SM2", "Profile for rendering on Shader Model 2 capable cards"));
+        mLayerDecl = {{"albedo_specular", PF_BYTE_RGBA}, {"normal_height", PF_BYTE_RGBA}};
 
-        // TODO - check hardware capabilities & use fallbacks if required (more profiles needed)
-        setActiveProfile(mProfiles.back());
+        mActiveProfile.reset(new SM2Profile(this));
 
         using namespace RTShader;
 
@@ -82,7 +81,7 @@ namespace Ogre
         }
 
         mMainRenderState.reset(new RenderState());
-        mMainRenderState->setLightCount(Vector3i(0, 1, 0));
+        mMainRenderState->setLightCount(1);
         mMainRenderState->addTemplateSubRenderStates(
             {"TerrainTransform", "TerrainSurface", SRS_PER_PIXEL_LIGHTING, SRS_FOG});
     }
@@ -93,17 +92,13 @@ namespace Ogre
     }
     //---------------------------------------------------------------------
     //---------------------------------------------------------------------
-    TerrainMaterialGeneratorA::SM2Profile::SM2Profile(TerrainMaterialGenerator* parent, const String& name, const String& desc)
-        : Profile(parent, name, desc)
+    TerrainMaterialGeneratorA::SM2Profile::SM2Profile(TerrainMaterialGeneratorA* parent)
+        : mParent(parent)
         , mLayerNormalMappingEnabled(true)
         , mLayerParallaxMappingEnabled(true)
+        , mLayerParallaxOcclusionMappingEnabled(true)
         , mLayerSpecularMappingEnabled(true)
-        , mGlobalColourMapEnabled(true)
-        , mLightmapEnabled(true)
-        , mCompositeMapEnabled(true)
-        , mReceiveDynamicShadows(true)
         , mPSSM(0)
-        , mLowLodShadows(false)
     {
     }
     //---------------------------------------------------------------------
@@ -111,7 +106,7 @@ namespace Ogre
     {
     }   
     //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::requestOptions(Terrain* terrain)
+    void TerrainMaterialGeneratorA::requestOptions(Terrain* terrain)
     {
         terrain->_setMorphRequired(true);
         terrain->_setNormalMapRequired(true);
@@ -119,11 +114,6 @@ namespace Ogre
         terrain->_setCompositeMapRequired(mCompositeMapEnabled);
     }
     //---------------------------------------------------------------------
-    bool TerrainMaterialGeneratorA::SM2Profile::isVertexCompressionSupported() const
-    {
-        return true;
-    }
-    //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::setLayerNormalMappingEnabled(bool enabled)
     {
         if (enabled != mLayerNormalMappingEnabled)
@@ -142,6 +132,15 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
+    void TerrainMaterialGeneratorA::SM2Profile::setLayerParallaxOcclusionMappingEnabled(bool enabled)
+    {
+        if (enabled != mLayerParallaxOcclusionMappingEnabled)
+        {
+            mLayerParallaxOcclusionMappingEnabled = enabled;
+            mParent->_markChanged();
+        }
+    }
+    //---------------------------------------------------------------------
     void TerrainMaterialGeneratorA::SM2Profile::setLayerSpecularMappingEnabled(bool enabled)
     {
         if (enabled != mLayerSpecularMappingEnabled)
@@ -151,39 +150,30 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
-    void  TerrainMaterialGeneratorA::SM2Profile::setGlobalColourMapEnabled(bool enabled)
-    {
-        if (enabled != mGlobalColourMapEnabled)
-        {
-            mGlobalColourMapEnabled = enabled;
-            mParent->_markChanged();
-        }
-    }
-    //---------------------------------------------------------------------
-    void  TerrainMaterialGeneratorA::SM2Profile::setLightmapEnabled(bool enabled)
+    void  TerrainMaterialGeneratorA::setLightmapEnabled(bool enabled)
     {
         if (enabled != mLightmapEnabled)
         {
             mLightmapEnabled = enabled;
-            mParent->_markChanged();
+            _markChanged();
         }
     }
     //---------------------------------------------------------------------
-    void  TerrainMaterialGeneratorA::SM2Profile::setCompositeMapEnabled(bool enabled)
+    void  TerrainMaterialGeneratorA::setCompositeMapEnabled(bool enabled)
     {
         if (enabled != mCompositeMapEnabled)
         {
             mCompositeMapEnabled = enabled;
-            mParent->_markChanged();
+            _markChanged();
         }
     }
     //---------------------------------------------------------------------
-    void  TerrainMaterialGeneratorA::SM2Profile::setReceiveDynamicShadowsEnabled(bool enabled)
+    void  TerrainMaterialGeneratorA::setReceiveDynamicShadowsEnabled(bool enabled)
     {
         if (enabled != mReceiveDynamicShadows)
         {
             mReceiveDynamicShadows = enabled;
-            mParent->_markChanged();
+            _markChanged();
         }
     }
     //---------------------------------------------------------------------
@@ -196,12 +186,12 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::setReceiveDynamicShadowsLowLod(bool enabled)
+    void TerrainMaterialGeneratorA::setReceiveDynamicShadowsLowLod(bool enabled)
     {
         if (enabled != mLowLodShadows)
         {
             mLowLodShadows = enabled;
-            mParent->_markChanged();
+            _markChanged();
         }
     }
     //---------------------------------------------------------------------
@@ -301,12 +291,13 @@ namespace Ogre
             auto surface = mainRenderState->getSubRenderState("TerrainSurface");
             OgreAssert(surface, "TerrainSurface SubRenderState not found");
             surface->setParameter("use_parallax_mapping", std::to_string(mLayerParallaxMappingEnabled));
+            surface->setParameter("use_parallax_occlusion_mapping", std::to_string(mLayerParallaxOcclusionMappingEnabled));
             surface->setParameter("use_specular_mapping", std::to_string(mLayerSpecularMappingEnabled));
             if(isShadowingEnabled(HIGH_LOD, terrain))
             {
-                auto pssm = ShaderGenerator::getSingleton().createSubRenderState<IntegratedPSSM3>();
+                auto pssm = ShaderGenerator::getSingleton().createSubRenderState(SRS_INTEGRATED_PSSM3);
                 if(mPSSM)
-                    pssm->setSplitPoints(mPSSM->getSplitPoints());
+                    pssm->setParameter("split_points", mPSSM->getSplitPoints());
                 pssm->preAddToRenderState(mainRenderState.get(), pass, pass);
                 mainRenderState->addSubRenderStateInstance(pssm);
             }
@@ -321,7 +312,7 @@ namespace Ogre
         pass->getUserObjectBindings().setUserAny(TargetRenderState::UserKey, mainRenderState);
 
         // LOD
-        if(mCompositeMapEnabled)
+        if(mParent->isCompositeMapEnabled())
         {
             Technique* tech = mat->createTechnique();
             tech->setLodIndex(1);
@@ -340,10 +331,10 @@ namespace Ogre
                 if (isShadowingEnabled(LOW_LOD, terrain))
                 {
                     // light count needed to enable PSSM3
-                    lod1RenderState->setLightCount(Vector3i(0, 1, 0));
-                    auto pssm = ShaderGenerator::getSingleton().createSubRenderState<IntegratedPSSM3>();
+                    lod1RenderState->setLightCount(1);
+                    auto pssm = ShaderGenerator::getSingleton().createSubRenderState(SRS_INTEGRATED_PSSM3);
                     if(mPSSM)
-                        pssm->setSplitPoints(mPSSM->getSplitPoints());
+                        pssm->setParameter("split_points", mPSSM->getSplitPoints());
                     pssm->preAddToRenderState(lod1RenderState.get(), pass, pass);
                     lod1RenderState->addSubRenderStateInstance(pssm);
                 }
@@ -360,12 +351,12 @@ namespace Ogre
             mat->setLodLevels({TerrainGlobalOptions::getSingleton().getCompositeMapDistance()});
         }
 
-        updateParams(mat, terrain);
+        mParent->updateParams(mat, terrain);
 
         return mat;
     }
     //---------------------------------------------------------------------
-    MaterialPtr TerrainMaterialGeneratorA::SM2Profile::generateForCompositeMap(const Terrain* terrain)
+    MaterialPtr TerrainMaterialGeneratorA::generateForCompositeMap(const Terrain* terrain)
     {
         // re-use old material if exists
         MaterialPtr mat = terrain->_getCompositeMapMaterial();
@@ -390,7 +381,7 @@ namespace Ogre
         pass->getUserObjectBindings().setUserAny("Terrain", terrain);
 
         auto compRenderState = std::make_shared<TargetRenderState>();
-        compRenderState->setLightCount(Vector3i(0, 1, 0));
+        compRenderState->setLightCount(1);
 
         try
         {
@@ -415,13 +406,12 @@ namespace Ogre
     //---------------------------------------------------------------------
     bool TerrainMaterialGeneratorA::SM2Profile::isShadowingEnabled(TechniqueType tt, const Terrain* terrain) const
     {
-        return getReceiveDynamicShadowsEnabled() && tt != RENDER_COMPOSITE_MAP && 
-            (tt != LOW_LOD || mLowLodShadows) &&
-            terrain->getSceneManager()->isShadowTechniqueTextureBased();
-
+        return mParent->getReceiveDynamicShadowsEnabled() && tt != RENDER_COMPOSITE_MAP &&
+               (tt != LOW_LOD || mParent->getReceiveDynamicShadowsLowLod()) &&
+               terrain->getSceneManager()->isShadowTechniqueTextureBased();
     }
     //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::updateParams(const MaterialPtr& mat, const Terrain* terrain)
+    void TerrainMaterialGeneratorA::updateParams(const MaterialPtr& mat, const Terrain* terrain)
     {
         using namespace RTShader;
         auto mainRenderState = any_cast<TargetRenderStatePtr>(
@@ -450,7 +440,7 @@ namespace Ogre
         }
     }
     //---------------------------------------------------------------------
-    void TerrainMaterialGeneratorA::SM2Profile::updateParamsForCompositeMap(const MaterialPtr& mat, const Terrain* terrain)
+    void TerrainMaterialGeneratorA::updateParamsForCompositeMap(const MaterialPtr& mat, const Terrain* terrain)
     {
         using namespace RTShader;
         auto mainRenderState = any_cast<TargetRenderStatePtr>(
