@@ -705,14 +705,6 @@ namespace Ogre
                 writeValue(pPass->getPolygonModeOverrideable() ? "on" : "off");
             }
 
-            // normalise normals
-            if (mDefaults ||
-                pPass->getNormaliseNormals() != false)
-            {
-                writeAttribute(3, "normalise_normals");
-                writeValue(pPass->getNormaliseNormals() ? "on" : "off");
-            }
-
             //fog override
             if (mDefaults ||
                 pPass->getFogOverride() != false)
@@ -818,7 +810,6 @@ namespace Ogre
         case TextureUnitState::TAM_MIRROR:
             return "mirror";
         case TextureUnitState::TAM_WRAP:
-        case TextureUnitState::TAM_UNKNOWN:
             return "wrap";
         }
 
@@ -1662,7 +1653,6 @@ namespace Ogre
                 const GpuProgramParameters::AutoConstantDefinition* autoConstDef =
                     GpuProgramParameters::getAutoConstantDefinition(autoEntry->paramType);
 
-                assert(autoConstDef && "Bad auto constant Definition Table");
                 // output auto constant name
                 writeValue(quoteWord(autoConstDef->name), useMainBuffer);
                 // output data if it uses it
