@@ -72,7 +72,7 @@ struct OgreIOStream : public Assimp::IOStream
 {
     DataStreamPtr stream;
 
-    OgreIOStream(DataStreamPtr _stream) : stream(_stream) {}
+    OgreIOStream(const DataStreamPtr& _stream) : stream(_stream) {}
 
     size_t Read(void* pvBuffer, size_t pSize, size_t pCount) override
     {
@@ -427,7 +427,15 @@ bool AssimpLoader::_load(const char* name, Assimp::Importer& importer, Mesh* mes
         if(tex->mHeight == 0)
         {
             auto stream = std::make_shared<MemoryDataStream>(tex->pcData, tex->mWidth, false);
-            img.load(stream, tex->achFormatHint);
+            try
+            {
+                img.load(stream, tex->achFormatHint);
+            }
+            catch (Exception& e)
+            {
+                LogManager::getSingleton().logError("Could not load embedded image - " + e.getDescription());
+                continue;
+            }
         }
         else
         {
@@ -813,8 +821,6 @@ bool AssimpLoader::isNodeNeeded(const char* name)
 
 void AssimpLoader::grabBoneNamesFromNode(const aiScene* mScene, const aiNode* pNode)
 {
-    static int meshNum = 0;
-    meshNum++;
     if (pNode->mNumMeshes > 0)
     {
         for (unsigned int idx = 0; idx < pNode->mNumMeshes; ++idx)
@@ -1026,11 +1032,17 @@ static MaterialPtr createMaterial(const aiMaterial* mat, const Ogre::String &gro
             LogManager::getSingleton().logMessage("Found normal map: " + basename);
         }
 
+        auto tus = omat->getTechnique(0)->getPass(0)->createTextureUnitState(basename);
+
+        // mark as normal map
+        shaderGen->_markNonFFP(tus);
+        uint16 texureIdx = tus->getParent()->getNumTextureUnitStates() - 1;
+
         shaderGen->createShaderBasedTechnique(omat->getTechnique(0), MSN_SHADERGEN);
         auto rs = shaderGen->getRenderState(MSN_SHADERGEN, *omat, 0);
         auto srs = shaderGen->createSubRenderState("NormalMap");
 
-        srs->setParameter("texture", basename);
+        srs->setParameter("texture_index", std::to_string(texureIdx));
         rs->addTemplateSubRenderState(srs);
     }
 
