@@ -4,26 +4,25 @@ This source file is part of OGRE
 (Object-oriented Graphics Rendering Engine)
 For the latest info, see http://www.ogre3d.org/
 
-Copyright (c) 2000-2006 Torus Knot Software Ltd
-Also see acknowledgements in Readme.html
+Copyright (c) 2000-2014 Torus Knot Software Ltd
 
-This program is free software; you can redistribute it and/or modify it under
-the terms of the GNU Lesser General Public License as published by the Free Software
-Foundation; either version 2 of the License, or (at your option) any later
-version.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
-This program is distributed in the hope that it will be useful, but WITHOUT
-ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
 
-You should have received a copy of the GNU Lesser General Public License along with
-this program; if not, write to the Free Software Foundation, Inc., 59 Temple
-Place - Suite 330, Boston, MA 02111-1307, USA, or go to
-http://www.gnu.org/copyleft/lesser.txt.
-
-You may alternatively use this source under the terms of a specific version of
-the OGRE Unrestricted License provided you have obtained such a license from
-Torus Knot Software Ltd.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
 -----------------------------------------------------------------------------
 */
 /***************************************************************************
@@ -32,35 +31,14 @@ octreescenemanager.cpp  -  description
 begin                : Fri Sep 27 2002
 copyright            : (C) 2002 by Jon Anderson
 email                : janders@users.sf.net
- 
-Enhancements 2003 - 2004 (C) The OGRE Team
- 
+  
 ***************************************************************************/
 
-#include <OgreOctreeSceneManager.h>
-#include <OgreOctreeSceneQuery.h>
-#include <OgreOctreeNode.h>
-#include <OgreOctreeCamera.h>
-#include <OgreRenderSystem.h>
-
-
-extern "C"
-{
-    void findNodesInBox( Ogre::SceneManager *sm,
-                         const Ogre::AxisAlignedBox &box,
-                         std::list < Ogre::SceneNode * > &list,
-                         Ogre::SceneNode *exclude )
-    {
-        static_cast<Ogre::OctreeSceneManager*>( sm ) -> findNodesIn( box, list, exclude );
-    }
-    void findNodesInSphere( Ogre::SceneManager *sm,
-                            const Ogre::Sphere &sphere,
-                            std::list < Ogre::SceneNode * > &list,
-                            Ogre::SceneNode *exclude )
-    {
-        static_cast<Ogre::OctreeSceneManager*>( sm ) -> findNodesIn( sphere, list, exclude );
-    }
-}
+#include "OgreOctreeSceneManager.h"
+#include "OgreOctreeSceneQuery.h"
+#include "OgreOctreeNode.h"
+#include "OgreOctreeCamera.h"
+#include "OgreWireBoundingBox.h"
 
 namespace Ogre
 {
@@ -72,13 +50,13 @@ enum Intersection
 };
 int OctreeSceneManager::intersect_call = 0;
 
-Intersection intersect( const Ray &one, const AxisAlignedBox &two )
+static Intersection intersect( const Ray &one, const AxisAlignedBox &two )
 {
     OctreeSceneManager::intersect_call++;
     // Null box?
     if (two.isNull()) return OUTSIDE;
-	// Infinite box?
-	if (two.isInfinite()) return INTERSECT;
+    // Infinite box?
+    if (two.isInfinite()) return INTERSECT;
 
     bool inside = true;
     const Vector3& twoMin = two.getMinimum();
@@ -143,13 +121,13 @@ Intersection intersect( const Ray &one, const AxisAlignedBox &two )
 
 /** Checks how the second box intersects with the first.
 */
-Intersection intersect( const PlaneBoundedVolume &one, const AxisAlignedBox &two )
+static Intersection intersect( const PlaneBoundedVolume &one, const AxisAlignedBox &two )
 {
     OctreeSceneManager::intersect_call++;
     // Null box?
     if (two.isNull()) return OUTSIDE;
-	// Infinite box?
-	if (two.isInfinite()) return INTERSECT;
+    // Infinite box?
+    if (two.isInfinite()) return INTERSECT;
 
     // Get centre of the box
     Vector3 centre = two.getCenter();
@@ -184,13 +162,13 @@ Intersection intersect( const PlaneBoundedVolume &one, const AxisAlignedBox &two
 
 /** Checks how the second box intersects with the first.
 */
-Intersection intersect( const AxisAlignedBox &one, const AxisAlignedBox &two )
+static Intersection intersect( const AxisAlignedBox &one, const AxisAlignedBox &two )
 {
     OctreeSceneManager::intersect_call++;
     // Null box?
     if (one.isNull() || two.isNull()) return OUTSIDE;
-	if (one.isInfinite()) return INSIDE;
-	if (two.isInfinite()) return INTERSECT;
+    if (one.isInfinite()) return INSIDE;
+    if (two.isInfinite()) return INTERSECT;
 
 
     const Vector3& insideMin = two.getMinimum();
@@ -225,12 +203,12 @@ Intersection intersect( const AxisAlignedBox &one, const AxisAlignedBox &two )
 
 /** Checks how the box intersects with the sphere.
 */
-Intersection intersect( const Sphere &one, const AxisAlignedBox &two )
+static Intersection intersect( const Sphere &one, const AxisAlignedBox &two )
 {
     OctreeSceneManager::intersect_call++;
     // Null box?
     if (two.isNull()) return OUTSIDE;
-	if (two.isInfinite()) return INTERSECT;
+    if (two.isInfinite()) return INTERSECT;
 
     float sradius = one.getRadius();
 
@@ -311,7 +289,7 @@ OctreeSceneManager::OctreeSceneManager(const String& name, AxisAlignedBox &box,
 
 const String& OctreeSceneManager::getTypeName(void) const
 {
-	return OctreeSceneManagerFactory::FACTORY_TYPE_NAME;
+    return OctreeSceneManagerFactory::FACTORY_TYPE_NAME;
 }
 
 void OctreeSceneManager::init( AxisAlignedBox &box, int depth )
@@ -356,29 +334,29 @@ OctreeSceneManager::~OctreeSceneManager()
 {
 
     if ( mOctree )
-	{
+    {
         OGRE_DELETE mOctree;
-		mOctree = 0;
-	}
+        mOctree = 0;
+    }
 }
 
 Camera * OctreeSceneManager::createCamera( const String &name )
 {
-	// Check name not used
-	if (mCameras.find(name) != mCameras.end())
-	{
-		OGRE_EXCEPT(
-			Exception::ERR_DUPLICATE_ITEM,
-			"A camera with the name " + name + " already exists",
-			"OctreeSceneManager::createCamera" );
-	}
+    // Check name not used
+    if (mCameras.find(name) != mCameras.end())
+    {
+        OGRE_EXCEPT(
+            Exception::ERR_DUPLICATE_ITEM,
+            "A camera with the name " + name + " already exists",
+            "OctreeSceneManager::createCamera" );
+    }
 
-	Camera * c = OGRE_NEW OctreeCamera( name, this );
-    mCameras.insert( CameraList::value_type( name, c ) );
+    Camera * c = OGRE_NEW OctreeCamera( name, this );
+    mCameras.emplace(name, c);
 
-	// create visible bounds aab map entry
-	mCamVisibleObjectsMap[c] = VisibleObjectsBoundsInfo();
-	
+    // create visible bounds aab map entry
+    mCamVisibleObjectsMap[c] = VisibleObjectsBoundsInfo();
+    
     return c;
 }
 
@@ -415,9 +393,9 @@ void OctreeSceneManager::_updateOctreeNode( OctreeNode * onode )
     if ( box.isNull() )
         return ;
 
-	// Skip if octree has been destroyed (shutdown conditions)
-	if (!mOctree)
-		return;
+    // Skip if octree has been destroyed (shutdown conditions)
+    if (!mOctree)
+        return;
 
     if ( onode -> getOctant() == 0 )
     {
@@ -445,9 +423,9 @@ void OctreeSceneManager::_updateOctreeNode( OctreeNode * onode )
 */
 void OctreeSceneManager::_removeOctreeNode( OctreeNode * n )
 {
-	// Skip if octree has been destroyed (shutdown conditions)
-	if (!mOctree)
-		return;
+    // Skip if octree has been destroyed (shutdown conditions)
+    if (!mOctree)
+        return;
 
     Octree * oct = n -> getOctant();
 
@@ -463,11 +441,11 @@ void OctreeSceneManager::_removeOctreeNode( OctreeNode * n )
 void OctreeSceneManager::_addOctreeNode( OctreeNode * n, Octree *octant, int depth )
 {
 
-	// Skip if octree has been destroyed (shutdown conditions)
-	if (!mOctree)
-		return;
+    // Skip if octree has been destroyed (shutdown conditions)
+    if (!mOctree)
+        return;
 
-	const AxisAlignedBox& bx = n -> _getWorldAABB();
+    const AxisAlignedBox& bx = n -> _getWorldAABB();
 
 
     //if the octree is twice as big as the scene node,
@@ -556,18 +534,18 @@ void OctreeSceneManager::_alertVisibleObjects( void )
         "Function doesn't do as advertised",
         "OctreeSceneManager::_alertVisibleObjects" );
 
-    NodeList::iterator it = mVisible.begin();
-
-    while ( it != mVisible.end() )
-    {
-        OctreeNode * node = *it;
-
-        ++it;
-    }
+//    Octree::NodeList::iterator it = mVisible.begin();
+//
+//    while ( it != mVisible.end() )
+//    {
+//        OctreeNode * node = *it;
+//
+//        ++it;
+//    }
 }
 
 void OctreeSceneManager::_findVisibleObjects(Camera * cam, 
-	VisibleObjectsBoundsInfo* visibleBounds, bool onlyShadowCasters )
+    VisibleObjectsBoundsInfo* visibleBounds, bool onlyShadowCasters )
 {
 
     getRenderQueue()->clear();
@@ -578,7 +556,7 @@ void OctreeSceneManager::_findVisibleObjects(Camera * cam,
 
     //walk the octree, adding all visible Octreenodes nodes to the render queue.
     walkOctree( static_cast < OctreeCamera * > ( cam ), getRenderQueue(), mOctree, 
-				visibleBounds, false, onlyShadowCasters );
+                visibleBounds, false, onlyShadowCasters );
 
     // Show the octree boxes & cull camera if required
     if ( mShowBoxes )
@@ -591,8 +569,8 @@ void OctreeSceneManager::_findVisibleObjects(Camera * cam,
 }
 
 void OctreeSceneManager::walkOctree( OctreeCamera *camera, RenderQueue *queue, 
-	Octree *octant, VisibleObjectsBoundsInfo* visibleBounds, 
-	bool foundvisible, bool onlyShadowCasters )
+    Octree *octant, VisibleObjectsBoundsInfo* visibleBounds, 
+    bool foundvisible, bool onlyShadowCasters )
 {
 
     //return immediately if nothing is in the node.
@@ -624,7 +602,7 @@ void OctreeSceneManager::walkOctree( OctreeCamera *camera, RenderQueue *queue,
     {
 
         //Add stuff to be rendered;
-        NodeList::iterator it = octant -> mNodes.begin();
+        Octree::NodeList::iterator it = octant -> mNodes.begin();
 
         if ( mShowBoxes )
         {
@@ -651,12 +629,8 @@ void OctreeSceneManager::walkOctree( OctreeCamera *camera, RenderQueue *queue,
 
                 mVisible.push_back( sn );
 
-                if ( mDisplayNodes )
-                    queue -> addRenderable( sn );
-
-                // check if the scene manager or this node wants the bounding box shown.
-                if (sn->getShowBoundingBox() || mShowBoundingBoxes)
-                    sn->_addBoundingBoxToQueue(queue);
+                if (getDebugDrawer())
+                    getDebugDrawer()->drawSceneNode(sn);
             }
 
             ++it;
@@ -693,323 +667,323 @@ void OctreeSceneManager::walkOctree( OctreeCamera *camera, RenderQueue *queue,
 }
 
 // --- non template versions
-void _findNodes( const AxisAlignedBox &t, std::list < SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
+static void _findNodes( const AxisAlignedBox &t, std::list< SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
 {
 
-	if ( !full )
-	{
-		AxisAlignedBox obox;
-		octant -> _getCullBounds( &obox );
+    if ( !full )
+    {
+        AxisAlignedBox obox;
+        octant -> _getCullBounds( &obox );
 
-		Intersection isect = intersect( t, obox );
+        Intersection isect = intersect( t, obox );
 
-		if ( isect == OUTSIDE )
-			return ;
+        if ( isect == OUTSIDE )
+            return ;
 
-		full = ( isect == INSIDE );
-	}
+        full = ( isect == INSIDE );
+    }
 
 
-	NodeList::iterator it = octant -> mNodes.begin();
+    Octree::NodeList::iterator it = octant -> mNodes.begin();
 
-	while ( it != octant -> mNodes.end() )
-	{
-		OctreeNode * on = ( *it );
+    while ( it != octant -> mNodes.end() )
+    {
+        OctreeNode * on = ( *it );
 
-		if ( on != exclude )
-		{
-			if ( full )
-			{
-				list.push_back( on );
-			}
+        if ( on != exclude )
+        {
+            if ( full )
+            {
+                list.push_back( on );
+            }
 
-			else
-			{
-				Intersection nsect = intersect( t, on -> _getWorldAABB() );
+            else
+            {
+                Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				if ( nsect != OUTSIDE )
-				{
-					list.push_back( on );
-				}
-			}
+                if ( nsect != OUTSIDE )
+                {
+                    list.push_back( on );
+                }
+            }
 
-		}
+        }
 
-		++it;
-	}
+        ++it;
+    }
 
-	Octree* child;
+    Octree* child;
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
 }
 
-void _findNodes( const Sphere &t, std::list < SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
+static void _findNodes( const Sphere &t, std::list< SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
 {
 
-	if ( !full )
-	{
-		AxisAlignedBox obox;
-		octant -> _getCullBounds( &obox );
+    if ( !full )
+    {
+        AxisAlignedBox obox;
+        octant -> _getCullBounds( &obox );
 
-		Intersection isect = intersect( t, obox );
+        Intersection isect = intersect( t, obox );
 
-		if ( isect == OUTSIDE )
-			return ;
+        if ( isect == OUTSIDE )
+            return ;
 
-		full = ( isect == INSIDE );
-	}
+        full = ( isect == INSIDE );
+    }
 
 
-	NodeList::iterator it = octant -> mNodes.begin();
+    Octree::NodeList::iterator it = octant -> mNodes.begin();
 
-	while ( it != octant -> mNodes.end() )
-	{
-		OctreeNode * on = ( *it );
+    while ( it != octant -> mNodes.end() )
+    {
+        OctreeNode * on = ( *it );
 
-		if ( on != exclude )
-		{
-			if ( full )
-			{
-				list.push_back( on );
-			}
+        if ( on != exclude )
+        {
+            if ( full )
+            {
+                list.push_back( on );
+            }
 
-			else
-			{
-				Intersection nsect = intersect( t, on -> _getWorldAABB() );
+            else
+            {
+                Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				if ( nsect != OUTSIDE )
-				{
-					list.push_back( on );
-				}
-			}
+                if ( nsect != OUTSIDE )
+                {
+                    list.push_back( on );
+                }
+            }
 
-		}
+        }
 
-		++it;
-	}
+        ++it;
+    }
 
-	Octree* child;
+    Octree* child;
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
 }
 
 
-void _findNodes( const PlaneBoundedVolume &t, std::list < SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
+static void _findNodes( const PlaneBoundedVolume &t, std::list< SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
 {
 
-	if ( !full )
-	{
-		AxisAlignedBox obox;
-		octant -> _getCullBounds( &obox );
+    if ( !full )
+    {
+        AxisAlignedBox obox;
+        octant -> _getCullBounds( &obox );
 
-		Intersection isect = intersect( t, obox );
+        Intersection isect = intersect( t, obox );
 
-		if ( isect == OUTSIDE )
-			return ;
+        if ( isect == OUTSIDE )
+            return ;
 
-		full = ( isect == INSIDE );
-	}
+        full = ( isect == INSIDE );
+    }
 
 
-	NodeList::iterator it = octant -> mNodes.begin();
+    Octree::NodeList::iterator it = octant -> mNodes.begin();
 
-	while ( it != octant -> mNodes.end() )
-	{
-		OctreeNode * on = ( *it );
+    while ( it != octant -> mNodes.end() )
+    {
+        OctreeNode * on = ( *it );
 
-		if ( on != exclude )
-		{
-			if ( full )
-			{
-				list.push_back( on );
-			}
+        if ( on != exclude )
+        {
+            if ( full )
+            {
+                list.push_back( on );
+            }
 
-			else
-			{
-				Intersection nsect = intersect( t, on -> _getWorldAABB() );
+            else
+            {
+                Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				if ( nsect != OUTSIDE )
-				{
-					list.push_back( on );
-				}
-			}
+                if ( nsect != OUTSIDE )
+                {
+                    list.push_back( on );
+                }
+            }
 
-		}
+        }
 
-		++it;
-	}
+        ++it;
+    }
 
-	Octree* child;
+    Octree* child;
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
 }
 
-void _findNodes( const Ray &t, std::list < SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
+static void _findNodes( const Ray &t, std::list< SceneNode * > &list, SceneNode *exclude, bool full, Octree *octant )
 {
 
-	if ( !full )
-	{
-		AxisAlignedBox obox;
-		octant -> _getCullBounds( &obox );
+    if ( !full )
+    {
+        AxisAlignedBox obox;
+        octant -> _getCullBounds( &obox );
 
-		Intersection isect = intersect( t, obox );
+        Intersection isect = intersect( t, obox );
 
-		if ( isect == OUTSIDE )
-			return ;
+        if ( isect == OUTSIDE )
+            return ;
 
-		full = ( isect == INSIDE );
-	}
+        full = ( isect == INSIDE );
+    }
 
 
-	NodeList::iterator it = octant -> mNodes.begin();
+    Octree::NodeList::iterator it = octant -> mNodes.begin();
 
-	while ( it != octant -> mNodes.end() )
-	{
-		OctreeNode * on = ( *it );
+    while ( it != octant -> mNodes.end() )
+    {
+        OctreeNode * on = ( *it );
 
-		if ( on != exclude )
-		{
-			if ( full )
-			{
-				list.push_back( on );
-			}
+        if ( on != exclude )
+        {
+            if ( full )
+            {
+                list.push_back( on );
+            }
 
-			else
-			{
-				Intersection nsect = intersect( t, on -> _getWorldAABB() );
+            else
+            {
+                Intersection nsect = intersect( t, on -> _getWorldAABB() );
 
-				if ( nsect != OUTSIDE )
-				{
-					list.push_back( on );
-				}
-			}
+                if ( nsect != OUTSIDE )
+                {
+                    list.push_back( on );
+                }
+            }
 
-		}
+        }
 
-		++it;
-	}
+        ++it;
+    }
 
-	Octree* child;
+    Octree* child;
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 0 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 0 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 0 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
-	if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
-		_findNodes( t, list, exclude, full, child );
+    if ( (child=octant -> mChildren[ 1 ][ 1 ][ 1 ]) != 0 )
+        _findNodes( t, list, exclude, full, child );
 
 }
 
-void OctreeSceneManager::findNodesIn( const AxisAlignedBox &box, std::list < SceneNode * > &list, SceneNode *exclude )
+void OctreeSceneManager::findNodesIn( const AxisAlignedBox &box, std::list< SceneNode * > &list, SceneNode *exclude )
 {
     _findNodes( box, list, exclude, false, mOctree );
 }
 
-void OctreeSceneManager::findNodesIn( const Sphere &sphere, std::list < SceneNode * > &list, SceneNode *exclude )
+void OctreeSceneManager::findNodesIn( const Sphere &sphere, std::list< SceneNode * > &list, SceneNode *exclude )
 {
     _findNodes( sphere, list, exclude, false, mOctree );
 }
 
-void OctreeSceneManager::findNodesIn( const PlaneBoundedVolume &volume, std::list < SceneNode * > &list, SceneNode *exclude )
+void OctreeSceneManager::findNodesIn( const PlaneBoundedVolume &volume, std::list< SceneNode * > &list, SceneNode *exclude )
 {
     _findNodes( volume, list, exclude, false, mOctree );
 }
 
-void OctreeSceneManager::findNodesIn( const Ray &r, std::list < SceneNode * > &list, SceneNode *exclude )
+void OctreeSceneManager::findNodesIn( const Ray &r, std::list< SceneNode * > &list, SceneNode *exclude )
 {
     _findNodes( r, list, exclude, false, mOctree );
 }
 
 void OctreeSceneManager::resize( const AxisAlignedBox &box )
 {
-    std::list < SceneNode * > nodes;
-    std::list < SceneNode * > ::iterator it;
+    std::list< SceneNode * > nodes;
+    std::list< SceneNode * > ::iterator it;
 
     _findNodes( mOctree->mBox, nodes, 0, true, mOctree );
 
@@ -1018,9 +992,9 @@ void OctreeSceneManager::resize( const AxisAlignedBox &box )
     mOctree = OGRE_NEW Octree( 0 );
     mOctree->mBox = box;
 
-	const Vector3 min = box.getMinimum();
-	const Vector3 max = box.getMaximum();
-	mOctree->mHalfSize = ( max - min ) * 0.5f;
+    const Vector3 &min = box.getMinimum();
+    const Vector3 &max = box.getMaximum();
+    mOctree->mHalfSize = ( max - min ) * 0.5f;
 
     it = nodes.begin();
 
@@ -1045,8 +1019,8 @@ bool OctreeSceneManager::setOption( const String & key, const void * val )
     else if ( key == "Depth" )
     {
         mMaxDepth = * static_cast < const int * > ( val );
-		// copy the box since resize will delete mOctree and reference won't work
-		AxisAlignedBox box = mOctree->mBox;
+        // copy the box since resize will delete mOctree and reference won't work
+        AxisAlignedBox box = mOctree->mBox;
         resize(box);
         return true;
     }
@@ -1099,7 +1073,7 @@ void OctreeSceneManager::clearScene(void)
 
 //---------------------------------------------------------------------
 AxisAlignedBoxSceneQuery*
-OctreeSceneManager::createAABBQuery(const AxisAlignedBox& box, unsigned long mask)
+OctreeSceneManager::createAABBQuery(const AxisAlignedBox& box, uint32 mask)
 {
     OctreeAxisAlignedBoxSceneQuery* q = OGRE_NEW OctreeAxisAlignedBoxSceneQuery(this);
     q->setBox(box);
@@ -1108,7 +1082,7 @@ OctreeSceneManager::createAABBQuery(const AxisAlignedBox& box, unsigned long mas
 }
 //---------------------------------------------------------------------
 SphereSceneQuery*
-OctreeSceneManager::createSphereQuery(const Sphere& sphere, unsigned long mask)
+OctreeSceneManager::createSphereQuery(const Sphere& sphere, uint32 mask)
 {
     OctreeSphereSceneQuery* q = OGRE_NEW OctreeSphereSceneQuery(this);
     q->setSphere(sphere);
@@ -1118,7 +1092,7 @@ OctreeSceneManager::createSphereQuery(const Sphere& sphere, unsigned long mask)
 //---------------------------------------------------------------------
 PlaneBoundedVolumeListSceneQuery*
 OctreeSceneManager::createPlaneBoundedVolumeQuery(const PlaneBoundedVolumeList& volumes,
-        unsigned long mask)
+        uint32 mask)
 {
     OctreePlaneBoundedVolumeListSceneQuery* q = OGRE_NEW OctreePlaneBoundedVolumeListSceneQuery(this);
     q->setVolumes(volumes);
@@ -1128,7 +1102,7 @@ OctreeSceneManager::createPlaneBoundedVolumeQuery(const PlaneBoundedVolumeList&
 
 //---------------------------------------------------------------------
 RaySceneQuery*
-OctreeSceneManager::createRayQuery(const Ray& ray, unsigned long mask)
+OctreeSceneManager::createRayQuery(const Ray& ray, uint32 mask)
 {
     OctreeRaySceneQuery* q = OGRE_NEW OctreeRaySceneQuery(this);
     q->setRay(ray);
@@ -1137,7 +1111,7 @@ OctreeSceneManager::createRayQuery(const Ray& ray, unsigned long mask)
 }
 //---------------------------------------------------------------------
 IntersectionSceneQuery*
-OctreeSceneManager::createIntersectionQuery(unsigned long mask)
+OctreeSceneManager::createIntersectionQuery(uint32 mask)
 {
 
     // Octree implementation performs WORSE for < 500 objects
@@ -1150,24 +1124,10 @@ OctreeSceneManager::createIntersectionQuery(unsigned long mask)
 //-----------------------------------------------------------------------
 const String OctreeSceneManagerFactory::FACTORY_TYPE_NAME = "OctreeSceneManager";
 //-----------------------------------------------------------------------
-void OctreeSceneManagerFactory::initMetaData(void) const
-{
-	mMetaData.typeName = FACTORY_TYPE_NAME;
-	mMetaData.description = "Scene manager organising the scene on the basis of an octree.";
-	mMetaData.sceneTypeMask = 0xFFFF; // support all types
-	mMetaData.worldGeometrySupported = false;
-}
-//-----------------------------------------------------------------------
 SceneManager* OctreeSceneManagerFactory::createInstance(
-	const String& instanceName)
+    const String& instanceName)
 {
-	return OGRE_NEW OctreeSceneManager(instanceName);
-}
-//-----------------------------------------------------------------------
-void OctreeSceneManagerFactory::destroyInstance(SceneManager* instance)
-{
-	OGRE_DELETE instance;
+    return OGRE_NEW OctreeSceneManager(instanceName);
 }
 
-
 }
