@@ -444,17 +444,17 @@ namespace Ogre
     /* enable/disable sky rendering */
     void PCZSceneManager::enableSky(bool onoff)
     {
-        if (mSkyBox.mSceneNode)
+        if (getSkyBoxNode())
         {
-            mSkyBox.setEnabled(onoff);
+            setSkyBoxEnabled(onoff);
         }
-        else if (mSkyDome.mSceneNode)
+        else if (getSkyDomeNode())
         {
-            mSkyDome.setEnabled(onoff);
+            setSkyDomeEnabled(onoff);
         }
-        else if (mSkyPlane.mSceneNode)
+        else if (getSkyPlaneNode())
         {
-            mSkyPlane.setEnabled(onoff);
+            setSkyPlaneEnabled(onoff);
         }
     }
 
@@ -466,19 +466,19 @@ namespace Ogre
             // if no zone specified, use default zone
             zone = mDefaultZone;
         }
-        if (auto node = (PCZSceneNode*)mSkyBox.mSceneNode)
+        if (auto node = (PCZSceneNode*)getSkyBoxNode())
         {
             node->setHomeZone(zone);
             node->anchorToHomeZone(zone);
             zone->setHasSky(true);
         }
-        if (auto node = (PCZSceneNode*)mSkyDome.mSceneNode)
+        if (auto node = (PCZSceneNode*)getSkyDomeNode())
         {
             node->setHomeZone(zone);
             node->anchorToHomeZone(zone);
             zone->setHasSky(true);
         }
-        if (auto node = (PCZSceneNode*)mSkyPlane.mSceneNode)
+        if (auto node = (PCZSceneNode*)getSkyPlaneNode())
         {
             node->setHomeZone(zone);
             node->anchorToHomeZone(zone);
@@ -978,45 +978,17 @@ namespace Ogre
             }
         } // release lock on lights collection
 
-        // from here on down this function is same as Ogre::SceneManager
-
-        // Update lights affecting frustum if changed
-        if (mCachedLightInfos != mTestLightInfos)
-        {
-            mLightsAffectingFrustum.resize(mTestLightInfos.size());
-            LightInfoList::const_iterator i;
-            LightList::iterator j = mLightsAffectingFrustum.begin();
-            for (i = mTestLightInfos.begin(); i != mTestLightInfos.end(); ++i, ++j)
-            {
-                *j = i->light;
-                // add cam distance for sorting if texture shadows
-                if (isShadowTechniqueTextureBased())
-                {
-                    (*j)->_calcTempSquareDist(camera->getDerivedPosition());
-                }
-            }
-
-            mShadowRenderer.sortLightsAffectingFrustum(mLightsAffectingFrustum);
-            // Use swap instead of copy operator for efficiently
-            mCachedLightInfos.swap(mTestLightInfos);
-
-            // notify light dirty, so all movable objects will re-populate
-            // their light list next time
-            _notifyLightsDirty();
-        }
-
+        updateCachedLightInfos(camera);
     }
     //---------------------------------------------------------------------
     void PCZSceneManager::ensureShadowTexturesCreated()
     {
-        bool shadowTextureConfigDirty = mShadowRenderer.mShadowTextureConfigDirty;
-        mShadowRenderer.ensureShadowTexturesCreated();
-        if (!shadowTextureConfigDirty) return;
+        SceneManager::ensureShadowTexturesCreated();
+        if (!isShadowTextureConfigDirty()) return;
 
-        size_t count = mShadowRenderer.mShadowTextureCameras.size();
-        for (size_t i = 0; i < count; ++i)
+        for (auto cam : getShadowTextureCameras())
         {
-            auto node = (PCZSceneNode*)mShadowRenderer.mShadowTextureCameras[i]->getParentSceneNode();
+            auto node = (PCZSceneNode*)cam->getParentSceneNode();
             addPCZSceneNode(node, mDefaultZone);
         }
     }
@@ -1152,8 +1124,8 @@ namespace Ogre
                                           getRenderQueue(),
                                           visibleBounds, 
                                           onlyShadowCasters,
-                                          mDisplayNodes,
-                                          mShowBoundingBoxes);
+                                          getDisplaySceneNodes(),
+                                          getShowBoundingBoxes());
     }
 
     void PCZSceneManager::findNodesIn( const AxisAlignedBox &box, 
@@ -1271,7 +1243,7 @@ namespace Ogre
     {
         if ( key == "ShowBoundingBoxes" )
         {
-            mShowBoundingBoxes = * static_cast < const bool * > ( val );
+            showBoundingBoxes(* static_cast < const bool * > ( val ));
             return true;
         }
 
@@ -1303,7 +1275,7 @@ namespace Ogre
         if ( key == "ShowBoundingBoxes" )
         {
 
-            * static_cast < bool * > ( val ) = mShowBoundingBoxes;
+            * static_cast < bool * > ( val ) = getShowBoundingBoxes();
             return true;
         }
         if ( key == "ShowPortals" )
@@ -1386,12 +1358,6 @@ namespace Ogre
     //-----------------------------------------------------------------------
     const String PCZSceneManagerFactory::FACTORY_TYPE_NAME = "PCZSceneManager";
     //-----------------------------------------------------------------------
-    void PCZSceneManagerFactory::initMetaData(void) const
-    {
-        mMetaData.typeName = FACTORY_TYPE_NAME;
-        mMetaData.worldGeometrySupported = false;
-    }
-    //-----------------------------------------------------------------------
     SceneManager* PCZSceneManagerFactory::createInstance(
         const String& instanceName)
     {
