@@ -46,7 +46,7 @@ namespace Ogre {
     public:
         String getName() const override { return "Box"; }
 
-        ParticleEmitter* createEmitter(ParticleSystem* psys) 
+        ParticleEmitter* createEmitter(ParticleSystem* psys) override
         {
             ParticleEmitter* emit = OGRE_NEW BoxEmitter(psys);
             mEmitters.push_back(emit);
